diff --git a/product/ERP5/interfaces/amount_generator.py b/product/ERP5/interfaces/amount_generator.py
index 7d77a1b5d78bb829d5e50330c09d23897e18fa2b..89bb550313f43d45847f2a41e080f5e54973bae0 100644
--- a/product/ERP5/interfaces/amount_generator.py
+++ b/product/ERP5/interfaces/amount_generator.py
@@ -43,14 +43,14 @@ class IAmountGenerator(Interface):
   and Trade Conditions.
   """
 
-  def getAggregatedAmountList(context, movement_list=None, rounding=False):
+  def getAggregatedAmountList(context, amount_list=None, rounding=False):
     """
     Returns an IAmountList generated by a model applied to the context.
     and aggregated according to the context divergence testers.
 
     context - an IMovementCollection, an IAmountList or an IAmount
 
     movement_list - optional IAmountList which can be passed explicitly
                     whenever context is an IMovementCollection and whenever
                     we want to filter context.getMovementList
 
@@ -63,15 +63,15 @@ class IAmountGenerator(Interface):
       - define how to retrieve divergence testers in the context
     """
 
-  def getGeneratedAmountList(context, movement_list=None, rounding=False):
+  def getGeneratedAmountList(context, amount_list=None, rounding=False):
     """
     Returns an IAmountList generated by a model applied to the context.
 
     context - an IMovementCollection, an IAmountList or an IAmount
 
     movement_list - optional IAmountList which can be passed explicitly
                     whenever context is an IMovementCollection and whenever
                     we want to filter context.getMovementList
 
     rounding - boolean argument, which controls if rounding shall be applied on
                generated movements or not
@@ -43,14 +43,14 @@ class IAmountGenerator(Interface):
     context - an IMovementCollection, an IAmountList or an IAmount
 
-    movement_list - optional IAmountList which can be passed explicitly
+    amount_list - optional IAmountList which can be passed explicitly
                     whenever context is an IMovementCollection and whenever
                     we want to filter context.getMovementList
@@ -63,15 +63,15 @@ class IAmountGenerator(Interface):
     context - an IMovementCollection, an IAmountList or an IAmount
 
-    movement_list - optional IAmountList which can be passed explicitly
-                    whenever context is an IMovementCollection and whenever
-                    we want to filter context.getMovementList
+    amount_list - optional IAmountList which can be passed explicitly
+                  whenever context is an IMovementCollection and whenever
+                  we want to filter context.getMovementList
 
     rounding - boolean argument, which controls if rounding shall be applied on